Index: /trunk/FACT++/src/DimDescriptionService.cc
===================================================================
--- /trunk/FACT++/src/DimDescriptionService.cc	(revision 10349)
+++ /trunk/FACT++/src/DimDescriptionService.cc	(revision 10350)
@@ -62,6 +62,7 @@
 //!
 //! @throws
 //!     If a server name couldn't be reliably determined a runtime_error
 //!     exception is thrown.
 //
 DimDescriptionService::DimDescriptionService(const std::string &name, const std::string &desc)
@@ -72,8 +73,11 @@
         const size_t p = name.find_first_of('/');
         if (p==string::npos)
-            throw runtime_error("Could not determine server name");
+            throw logic_error("Could not determine server name");
 
         service = name.substr(0, p);
     }
+
+    if (desc.find_first_of('\n')!=string::npos)
+            throw logic_error("Description for "+name+" contains '\\n'");
 
     service += "/SERVICE_DESC";
@@ -62,6 +62,7 @@
 //!
 //! @throws
-//!     If a server name couldn't be reliably determined a runtime_error
-//!     exception is thrown.
+//!     If a server name couldn't be reliably determined a logic_error
+//!     exception is thrown; if the given description contains a '\n'
+//!     also a logic_error is thrown.
 //
 DimDescriptionService::DimDescriptionService(const std::string &name, const std::string &desc)
